@@ -16,7 +16,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '2.0091';
+$VERSION = '2.0093';
 
 bootstrap DBD::mysql $VERSION;
 
@@ -660,6 +660,35 @@ such as books, magazine articles or CD-ROMs should be made to
 Alligator Descartes <I<descarte@hermetica.com>>.
 
 
+=head1 MAILING LIST SUPPORT
+
+This module is maintained and supported on a mailing list,
+
+    msql-mysql-modules@tcx.se
+
+To subscribe to this list, send a mail with the words
+
+    subscribe msql-mysql-modules
+
+or
+
+    subscribe msql-mysql-modules-digest
+
+in the first line of the body to mdomo@tcx.se. A mailing list archive is
+in preparation.
+
+Additionally you might try the dbi-user mailing list for questions about
+DBI and its modules in general. Subscribe via
+
+    http://www.fugue.com/dbi
+
+Mailing list archives are at
+
+     http://www.rosat.mpe-garching.mpg.de/mailing-lists/PerlDB-Interest/
+     http://outside.organic.com/mail-archives/dbi-users/
+     http://www.coe.missouri.edu/~faq/lists/dbi.html
+
+
 =head1 ADDITIONAL DBI INFORMATION
 
 Additional information on the DBI project can be found on the World
